Converts a specific amount of money from current currency (curr1) to desired currency (curr2)

fx_conversion(curr1, curr2, amt)

Arguments

curr1

A character vector which is the ticker of the current currency such as 'EUR'

curr2

A character vector which is the ticker of the desired currency to convert to such as 'USD'

amt

A double vector that is the amount of money to be converted

Value

A double vector. Amount of value converted from currency 1 to currency 2

Examples

fx_conversion('EUR', 'USD', 150.75)
#> Registered S3 method overwritten by 'quantmod':
#>   method            from
#>   as.zoo.data.frame zoo 
#> [1] 161.94