price_trend_viz.RdVisualizes trend of the exchange rate of a currency pair between the selected start date and end date.
price_trend_viz(curr, start_date, end_date, option)A character vector which is the ticker of the currency pair such as 'EURUSD'
A character vector which is the start date of the selected period of time
A character vector which is the end date of the selected period of time
A character vector which must be from 'open', high', "low', 'close'
A line plot that shows the trend of the exchange rate of a currency pair over the selected period of time.
price_trend_viz('EURUSD', '2018-12-31', '2022-12-31', 'close')